@@ -1,9 +1,10 @@
--- Setup file for a Gtk2Hs module. Contains only adjustments specific to this module,
--- all Gtk2Hs-specific boilerplate is stored in Gtk2HsSetup.hs which should be kept
--- identical across all modules.
+-- Adjustments specific to this package,
+-- all Gtk2Hs-specific boilerplate is kept in
+-- gtk2hs-buildtools:Gtk2HsSetup
+--
 import Distribution.Simple ( defaultMainWithHooks, UserHooks(postConf),
                              PackageIdentifier(..), PackageName(..) )
-import Gtk2HsSetup ( gtk2hsUserHooks, getPkgConfigPackages, checkGtk2hsBuildtools )
+import Gtk2HsSetup ( gtk2hsUserHooks, getPkgConfigPackages)
 import Distribution.Simple.Setup ( ConfigFlags(configVerbosity), fromFlag)
 import Distribution.Simple.LocalBuildInfo ( LocalBuildInfo(..) )
 import Distribution.Simple.BuildPaths ( autogenModulesDir )
@@ -13,8 +14,7 @@ import Distribution.Verbosity
 import Distribution.Simple.Utils
 import System.FilePath
 
-main = do
-  checkGtk2hsBuildtools ["gtk2hsC2hs", "gtk2hsTypeGen"]
+main =
   defaultMainWithHooks gtk2hsUserHooks {
 
     postConf = \args cf pd lbi -> do
@@ -42,4 +42,4 @@ writePangoVersionHeaderFile verbosity lbi (Version (major:minor:micro:_) []) = d
     targetFile = targetDir </> "hspangoversion.h"
 
 writeVersionHeaderFile _ _ version =
-  die $ "unexpected pango version number: " ++ display version
\ No newline at end of file
+  die $ "unexpected pango version number: " ++ display version
